0.9.9 API documentation: type_aligned.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

gtc/type_aligned.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 #if (GLM_CONFIG_ALIGNED_GENTYPES == GLM_DISABLE)
16 # error "GLM: Aligned gentypes require to enable C++ language extensions. Define GLM_FORCE_ALIGNED_GENTYPES before including GLM headers to use aligned types."
17 #endif
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # pragma message("GLM: GLM_GTC_type_aligned extension included")
21 #endif
22
23 #include "../mat4x4.hpp"
24 #include "../mat4x3.hpp"
25 #include "../mat4x2.hpp"
26 #include "../mat3x4.hpp"
27 #include "../mat3x3.hpp"
28 #include "../mat3x2.hpp"
29 #include "../mat2x4.hpp"
30 #include "../mat2x3.hpp"
31 #include "../mat2x2.hpp"
32 #include "../gtc/vec1.hpp"
33 #include "../vec2.hpp"
34 #include "../vec3.hpp"
35 #include "../vec4.hpp"
36
37 namespace glm
38 {
41
42 // -- *vec1 --
43
45 typedef vec<1, float, aligned_highp> aligned_highp_vec1;
46
48 typedef vec<1, float, aligned_mediump> aligned_mediump_vec1;
49
51 typedef vec<1, float, aligned_lowp> aligned_lowp_vec1;
52
54 typedef vec<1, double, aligned_highp> aligned_highp_dvec1;
55
57 typedef vec<1, double, aligned_mediump> aligned_mediump_dvec1;
58
60 typedef vec<1, double, aligned_lowp> aligned_lowp_dvec1;
61
63 typedef vec<1, int, aligned_highp> aligned_highp_ivec1;
64
66 typedef vec<1, int, aligned_mediump> aligned_mediump_ivec1;
67
69 typedef vec<1, int, aligned_lowp> aligned_lowp_ivec1;
70
72 typedef vec<1, uint, aligned_highp> aligned_highp_uvec1;
73
75 typedef vec<1, uint, aligned_mediump> aligned_mediump_uvec1;
76
78 typedef vec<1, uint, aligned_lowp> aligned_lowp_uvec1;
79
81 typedef vec<1, bool, aligned_highp> aligned_highp_bvec1;
82
84 typedef vec<1, bool, aligned_mediump> aligned_mediump_bvec1;
85
87 typedef vec<1, bool, aligned_lowp> aligned_lowp_bvec1;
88
90 typedef vec<1, float, packed_highp> packed_highp_vec1;
91
93 typedef vec<1, float, packed_mediump> packed_mediump_vec1;
94
96 typedef vec<1, float, packed_lowp> packed_lowp_vec1;
97
99 typedef vec<1, double, packed_highp> packed_highp_dvec1;
100
102 typedef vec<1, double, packed_mediump> packed_mediump_dvec1;
103
105 typedef vec<1, double, packed_lowp> packed_lowp_dvec1;
106
108 typedef vec<1, int, packed_highp> packed_highp_ivec1;
109
111 typedef vec<1, int, packed_mediump> packed_mediump_ivec1;
112
114 typedef vec<1, int, packed_lowp> packed_lowp_ivec1;
115
117 typedef vec<1, uint, packed_highp> packed_highp_uvec1;
118
120 typedef vec<1, uint, packed_mediump> packed_mediump_uvec1;
121
123 typedef vec<1, uint, packed_lowp> packed_lowp_uvec1;
124
126 typedef vec<1, bool, packed_highp> packed_highp_bvec1;
127
129 typedef vec<1, bool, packed_mediump> packed_mediump_bvec1;
130
132 typedef vec<1, bool, packed_lowp> packed_lowp_bvec1;
133
134 // -- *vec2 --
135
137 typedef vec<2, float, aligned_highp> aligned_highp_vec2;
138
140 typedef vec<2, float, aligned_mediump> aligned_mediump_vec2;
141
143 typedef vec<2, float, aligned_lowp> aligned_lowp_vec2;
144
146 typedef vec<2, double, aligned_highp> aligned_highp_dvec2;
147
149 typedef vec<2, double, aligned_mediump> aligned_mediump_dvec2;
150
152 typedef vec<2, double, aligned_lowp> aligned_lowp_dvec2;
153
155 typedef vec<2, int, aligned_highp> aligned_highp_ivec2;
156
158 typedef vec<2, int, aligned_mediump> aligned_mediump_ivec2;
159
161 typedef vec<2, int, aligned_lowp> aligned_lowp_ivec2;
162
164 typedef vec<2, uint, aligned_highp> aligned_highp_uvec2;
165
167 typedef vec<2, uint, aligned_mediump> aligned_mediump_uvec2;
168
170 typedef vec<2, uint, aligned_lowp> aligned_lowp_uvec2;
171
173 typedef vec<2, bool, aligned_highp> aligned_highp_bvec2;
174
176 typedef vec<2, bool, aligned_mediump> aligned_mediump_bvec2;
177
179 typedef vec<2, bool, aligned_lowp> aligned_lowp_bvec2;
180
182 typedef vec<2, float, packed_highp> packed_highp_vec2;
183
185 typedef vec<2, float, packed_mediump> packed_mediump_vec2;
186
188 typedef vec<2, float, packed_lowp> packed_lowp_vec2;
189
191 typedef vec<2, double, packed_highp> packed_highp_dvec2;
192
194 typedef vec<2, double, packed_mediump> packed_mediump_dvec2;
195
197 typedef vec<2, double, packed_lowp> packed_lowp_dvec2;
198
200 typedef vec<2, int, packed_highp> packed_highp_ivec2;
201
203 typedef vec<2, int, packed_mediump> packed_mediump_ivec2;
204
206 typedef vec<2, int, packed_lowp> packed_lowp_ivec2;
207
209 typedef vec<2, uint, packed_highp> packed_highp_uvec2;
210
212 typedef vec<2, uint, packed_mediump> packed_mediump_uvec2;
213
215 typedef vec<2, uint, packed_lowp> packed_lowp_uvec2;
216
218 typedef vec<2, bool, packed_highp> packed_highp_bvec2;
219
221 typedef vec<2, bool, packed_mediump> packed_mediump_bvec2;
222
224 typedef vec<2, bool, packed_lowp> packed_lowp_bvec2;
225
226 // -- *vec3 --
227
229 typedef vec<3, float, aligned_highp> aligned_highp_vec3;
230
232 typedef vec<3, float, aligned_mediump> aligned_mediump_vec3;
233
235 typedef vec<3, float, aligned_lowp> aligned_lowp_vec3;
236
238 typedef vec<3, double, aligned_highp> aligned_highp_dvec3;
239
241 typedef vec<3, double, aligned_mediump> aligned_mediump_dvec3;
242
244 typedef vec<3, double, aligned_lowp> aligned_lowp_dvec3;
245
247 typedef vec<3, int, aligned_highp> aligned_highp_ivec3;
248
250 typedef vec<3, int, aligned_mediump> aligned_mediump_ivec3;
251
253 typedef vec<3, int, aligned_lowp> aligned_lowp_ivec3;
254
256 typedef vec<3, uint, aligned_highp> aligned_highp_uvec3;
257
259 typedef vec<3, uint, aligned_mediump> aligned_mediump_uvec3;
260
262 typedef vec<3, uint, aligned_lowp> aligned_lowp_uvec3;
263
265 typedef vec<3, bool, aligned_highp> aligned_highp_bvec3;
266
268 typedef vec<3, bool, aligned_mediump> aligned_mediump_bvec3;
269
271 typedef vec<3, bool, aligned_lowp> aligned_lowp_bvec3;
272
274 typedef vec<3, float, packed_highp> packed_highp_vec3;
275
277 typedef vec<3, float, packed_mediump> packed_mediump_vec3;
278
280 typedef vec<3, float, packed_lowp> packed_lowp_vec3;
281
283 typedef vec<3, double, packed_highp> packed_highp_dvec3;
284
286 typedef vec<3, double, packed_mediump> packed_mediump_dvec3;
287
289 typedef vec<3, double, packed_lowp> packed_lowp_dvec3;
290
292 typedef vec<3, int, packed_highp> packed_highp_ivec3;
293
295 typedef vec<3, int, packed_mediump> packed_mediump_ivec3;
296
298 typedef vec<3, int, packed_lowp> packed_lowp_ivec3;
299
301 typedef vec<3, uint, packed_highp> packed_highp_uvec3;
302
304 typedef vec<3, uint, packed_mediump> packed_mediump_uvec3;
305
307 typedef vec<3, uint, packed_lowp> packed_lowp_uvec3;
308
310 typedef vec<3, bool, packed_highp> packed_highp_bvec3;
311
313 typedef vec<3, bool, packed_mediump> packed_mediump_bvec3;
314
316 typedef vec<3, bool, packed_lowp> packed_lowp_bvec3;
317
318 // -- *vec4 --
319
321 typedef vec<4, float, aligned_highp> aligned_highp_vec4;
322
324 typedef vec<4, float, aligned_mediump> aligned_mediump_vec4;
325
327 typedef vec<4, float, aligned_lowp> aligned_lowp_vec4;
328
330 typedef vec<4, double, aligned_highp> aligned_highp_dvec4;
331
333 typedef vec<4, double, aligned_mediump> aligned_mediump_dvec4;
334
336 typedef vec<4, double, aligned_lowp> aligned_lowp_dvec4;
337
339 typedef vec<4, int, aligned_highp> aligned_highp_ivec4;
340
342 typedef vec<4, int, aligned_mediump> aligned_mediump_ivec4;
343
345 typedef vec<4, int, aligned_lowp> aligned_lowp_ivec4;
346
348 typedef vec<4, uint, aligned_highp> aligned_highp_uvec4;
349
351 typedef vec<4, uint, aligned_mediump> aligned_mediump_uvec4;
352
354 typedef vec<4, uint, aligned_lowp> aligned_lowp_uvec4;
355
357 typedef vec<4, bool, aligned_highp> aligned_highp_bvec4;
358
360 typedef vec<4, bool, aligned_mediump> aligned_mediump_bvec4;
361
363 typedef vec<4, bool, aligned_lowp> aligned_lowp_bvec4;
364
366 typedef vec<4, float, packed_highp> packed_highp_vec4;
367
369 typedef vec<4, float, packed_mediump> packed_mediump_vec4;
370
372 typedef vec<4, float, packed_lowp> packed_lowp_vec4;
373
375 typedef vec<4, double, packed_highp> packed_highp_dvec4;
376
378 typedef vec<4, double, packed_mediump> packed_mediump_dvec4;
379
381 typedef vec<4, double, packed_lowp> packed_lowp_dvec4;
382
384 typedef vec<4, int, packed_highp> packed_highp_ivec4;
385
387 typedef vec<4, int, packed_mediump> packed_mediump_ivec4;
388
390 typedef vec<4, int, packed_lowp> packed_lowp_ivec4;
391
393 typedef vec<4, uint, packed_highp> packed_highp_uvec4;
394
396 typedef vec<4, uint, packed_mediump> packed_mediump_uvec4;
397
399 typedef vec<4, uint, packed_lowp> packed_lowp_uvec4;
400
402 typedef vec<4, bool, packed_highp> packed_highp_bvec4;
403
405 typedef vec<4, bool, packed_mediump> packed_mediump_bvec4;
406
408 typedef vec<4, bool, packed_lowp> packed_lowp_bvec4;
409
410 // -- *mat2 --
411
413 typedef mat<2, 2, float, aligned_highp> aligned_highp_mat2;
414
416 typedef mat<2, 2, float, aligned_mediump> aligned_mediump_mat2;
417
419 typedef mat<2, 2, float, aligned_lowp> aligned_lowp_mat2;
420
422 typedef mat<2, 2, double, aligned_highp> aligned_highp_dmat2;
423
425 typedef mat<2, 2, double, aligned_mediump> aligned_mediump_dmat2;
426
428 typedef mat<2, 2, double, aligned_lowp> aligned_lowp_dmat2;
429
431 typedef mat<2, 2, float, packed_highp> packed_highp_mat2;
432
434 typedef mat<2, 2, float, packed_mediump> packed_mediump_mat2;
435
437 typedef mat<2, 2, float, packed_lowp> packed_lowp_mat2;
438
440 typedef mat<2, 2, double, packed_highp> packed_highp_dmat2;
441
443 typedef mat<2, 2, double, packed_mediump> packed_mediump_dmat2;
444
446 typedef mat<2, 2, double, packed_lowp> packed_lowp_dmat2;
447
448 // -- *mat3 --
449
451 typedef mat<3, 3, float, aligned_highp> aligned_highp_mat3;
452
454 typedef mat<3, 3, float, aligned_mediump> aligned_mediump_mat3;
455
457 typedef mat<3, 3, float, aligned_lowp> aligned_lowp_mat3;
458
460 typedef mat<3, 3, double, aligned_highp> aligned_highp_dmat3;
461
463 typedef mat<3, 3, double, aligned_mediump> aligned_mediump_dmat3;
464
466 typedef mat<3, 3, double, aligned_lowp> aligned_lowp_dmat3;
467
469 typedef mat<3, 3, float, packed_highp> packed_highp_mat3;
470
472 typedef mat<3, 3, float, packed_mediump> packed_mediump_mat3;
473
475 typedef mat<3, 3, float, packed_lowp> packed_lowp_mat3;
476
478 typedef mat<3, 3, double, packed_highp> packed_highp_dmat3;
479
481 typedef mat<3, 3, double, packed_mediump> packed_mediump_dmat3;
482
484 typedef mat<3, 3, double, packed_lowp> packed_lowp_dmat3;
485
486 // -- *mat4 --
487
489 typedef mat<4, 4, float, aligned_highp> aligned_highp_mat4;
490
492 typedef mat<4, 4, float, aligned_mediump> aligned_mediump_mat4;
493
495 typedef mat<4, 4, float, aligned_lowp> aligned_lowp_mat4;
496
498 typedef mat<4, 4, double, aligned_highp> aligned_highp_dmat4;
499
501 typedef mat<4, 4, double, aligned_mediump> aligned_mediump_dmat4;
502
504 typedef mat<4, 4, double, aligned_lowp> aligned_lowp_dmat4;
505
507 typedef mat<4, 4, float, packed_highp> packed_highp_mat4;
508
510 typedef mat<4, 4, float, packed_mediump> packed_mediump_mat4;
511
513 typedef mat<4, 4, float, packed_lowp> packed_lowp_mat4;
514
516 typedef mat<4, 4, double, packed_highp> packed_highp_dmat4;
517
519 typedef mat<4, 4, double, packed_mediump> packed_mediump_dmat4;
520
522 typedef mat<4, 4, double, packed_lowp> packed_lowp_dmat4;
523
524 // -- *mat2x2 --
525
527 typedef mat<2, 2, float, aligned_highp> aligned_highp_mat2x2;
528
530 typedef mat<2, 2, float, aligned_mediump> aligned_mediump_mat2x2;
531
533 typedef mat<2, 2, float, aligned_lowp> aligned_lowp_mat2x2;
534
536 typedef mat<2, 2, double, aligned_highp> aligned_highp_dmat2x2;
537
539 typedef mat<2, 2, double, aligned_mediump> aligned_mediump_dmat2x2;
540
542 typedef mat<2, 2, double, aligned_lowp> aligned_lowp_dmat2x2;
543
545 typedef mat<2, 2, float, packed_highp> packed_highp_mat2x2;
546
548 typedef mat<2, 2, float, packed_mediump> packed_mediump_mat2x2;
549
551 typedef mat<2, 2, float, packed_lowp> packed_lowp_mat2x2;
552
554 typedef mat<2, 2, double, packed_highp> packed_highp_dmat2x2;
555
557 typedef mat<2, 2, double, packed_mediump> packed_mediump_dmat2x2;
558
560 typedef mat<2, 2, double, packed_lowp> packed_lowp_dmat2x2;
561
562 // -- *mat2x3 --
563
565 typedef mat<2, 3, float, aligned_highp> aligned_highp_mat2x3;
566
568 typedef mat<2, 3, float, aligned_mediump> aligned_mediump_mat2x3;
569
571 typedef mat<2, 3, float, aligned_lowp> aligned_lowp_mat2x3;
572
574 typedef mat<2, 3, double, aligned_highp> aligned_highp_dmat2x3;
575
577 typedef mat<2, 3, double, aligned_mediump> aligned_mediump_dmat2x3;
578
580 typedef mat<2, 3, double, aligned_lowp> aligned_lowp_dmat2x3;
581
583 typedef mat<2, 3, float, packed_highp> packed_highp_mat2x3;
584
586 typedef mat<2, 3, float, packed_mediump> packed_mediump_mat2x3;
587
589 typedef mat<2, 3, float, packed_lowp> packed_lowp_mat2x3;
590
592 typedef mat<2, 3, double, packed_highp> packed_highp_dmat2x3;
593
595 typedef mat<2, 3, double, packed_mediump> packed_mediump_dmat2x3;
596
598 typedef mat<2, 3, double, packed_lowp> packed_lowp_dmat2x3;
599
600 // -- *mat2x4 --
601
603 typedef mat<2, 4, float, aligned_highp> aligned_highp_mat2x4;
604
606 typedef mat<2, 4, float, aligned_mediump> aligned_mediump_mat2x4;
607
609 typedef mat<2, 4, float, aligned_lowp> aligned_lowp_mat2x4;
610
612 typedef mat<2, 4, double, aligned_highp> aligned_highp_dmat2x4;
613
615 typedef mat<2, 4, double, aligned_mediump> aligned_mediump_dmat2x4;
616
618 typedef mat<2, 4, double, aligned_lowp> aligned_lowp_dmat2x4;
619
621 typedef mat<2, 4, float, packed_highp> packed_highp_mat2x4;
622
624 typedef mat<2, 4, float, packed_mediump> packed_mediump_mat2x4;
625
627 typedef mat<2, 4, float, packed_lowp> packed_lowp_mat2x4;
628
630 typedef mat<2, 4, double, packed_highp> packed_highp_dmat2x4;
631
633 typedef mat<2, 4, double, packed_mediump> packed_mediump_dmat2x4;
634
636 typedef mat<2, 4, double, packed_lowp> packed_lowp_dmat2x4;
637
638 // -- *mat3x2 --
639
641 typedef mat<3, 2, float, aligned_highp> aligned_highp_mat3x2;
642
644 typedef mat<3, 2, float, aligned_mediump> aligned_mediump_mat3x2;
645
647 typedef mat<3, 2, float, aligned_lowp> aligned_lowp_mat3x2;
648
650 typedef mat<3, 2, double, aligned_highp> aligned_highp_dmat3x2;
651
653 typedef mat<3, 2, double, aligned_mediump> aligned_mediump_dmat3x2;
654
656 typedef mat<3, 2, double, aligned_lowp> aligned_lowp_dmat3x2;
657
659 typedef mat<3, 2, float, packed_highp> packed_highp_mat3x2;
660
662 typedef mat<3, 2, float, packed_mediump> packed_mediump_mat3x2;
663
665 typedef mat<3, 2, float, packed_lowp> packed_lowp_mat3x2;
666
668 typedef mat<3, 2, double, packed_highp> packed_highp_dmat3x2;
669
671 typedef mat<3, 2, double, packed_mediump> packed_mediump_dmat3x2;
672
674 typedef mat<3, 2, double, packed_lowp> packed_lowp_dmat3x2;
675
676 // -- *mat3x3 --
677
679 typedef mat<3, 3, float, aligned_highp> aligned_highp_mat3x3;
680
682 typedef mat<3, 3, float, aligned_mediump> aligned_mediump_mat3x3;
683
685 typedef mat<3, 3, float, aligned_lowp> aligned_lowp_mat3x3;
686
688 typedef mat<3, 3, double, aligned_highp> aligned_highp_dmat3x3;
689
691 typedef mat<3, 3, double, aligned_mediump> aligned_mediump_dmat3x3;
692
694 typedef mat<3, 3, double, aligned_lowp> aligned_lowp_dmat3x3;
695
697 typedef mat<3, 3, float, packed_highp> packed_highp_mat3x3;
698
700 typedef mat<3, 3, float, packed_mediump> packed_mediump_mat3x3;
701
703 typedef mat<3, 3, float, packed_lowp> packed_lowp_mat3x3;
704
706 typedef mat<3, 3, double, packed_highp> packed_highp_dmat3x3;
707
709 typedef mat<3, 3, double, packed_mediump> packed_mediump_dmat3x3;
710
712 typedef mat<3, 3, double, packed_lowp> packed_lowp_dmat3x3;
713
714 // -- *mat3x4 --
715
717 typedef mat<3, 4, float, aligned_highp> aligned_highp_mat3x4;
718
720 typedef mat<3, 4, float, aligned_mediump> aligned_mediump_mat3x4;
721
723 typedef mat<3, 4, float, aligned_lowp> aligned_lowp_mat3x4;
724
726 typedef mat<3, 4, double, aligned_highp> aligned_highp_dmat3x4;
727
729 typedef mat<3, 4, double, aligned_mediump> aligned_mediump_dmat3x4;
730
732 typedef mat<3, 4, double, aligned_lowp> aligned_lowp_dmat3x4;
733
735 typedef mat<3, 4, float, packed_highp> packed_highp_mat3x4;
736
738 typedef mat<3, 4, float, packed_mediump> packed_mediump_mat3x4;
739
741 typedef mat<3, 4, float, packed_lowp> packed_lowp_mat3x4;
742
744 typedef mat<3, 4, double, packed_highp> packed_highp_dmat3x4;
745
747 typedef mat<3, 4, double, packed_mediump> packed_mediump_dmat3x4;
748
750 typedef mat<3, 4, double, packed_lowp> packed_lowp_dmat3x4;
751
752 // -- *mat4x2 --
753
755 typedef mat<4, 2, float, aligned_highp> aligned_highp_mat4x2;
756
758 typedef mat<4, 2, float, aligned_mediump> aligned_mediump_mat4x2;
759
761 typedef mat<4, 2, float, aligned_lowp> aligned_lowp_mat4x2;
762
764 typedef mat<4, 2, double, aligned_highp> aligned_highp_dmat4x2;
765
767 typedef mat<4, 2, double, aligned_mediump> aligned_mediump_dmat4x2;
768
770 typedef mat<4, 2, double, aligned_lowp> aligned_lowp_dmat4x2;
771
773 typedef mat<4, 2, float, packed_highp> packed_highp_mat4x2;
774
776 typedef mat<4, 2, float, packed_mediump> packed_mediump_mat4x2;
777
779 typedef mat<4, 2, float, packed_lowp> packed_lowp_mat4x2;
780
782 typedef mat<4, 2, double, packed_highp> packed_highp_dmat4x2;
783
785 typedef mat<4, 2, double, packed_mediump> packed_mediump_dmat4x2;
786
788 typedef mat<4, 2, double, packed_lowp> packed_lowp_dmat4x2;
789
790 // -- *mat4x3 --
791
793 typedef mat<4, 3, float, aligned_highp> aligned_highp_mat4x3;
794
796 typedef mat<4, 3, float, aligned_mediump> aligned_mediump_mat4x3;
797
799 typedef mat<4, 3, float, aligned_lowp> aligned_lowp_mat4x3;
800
802 typedef mat<4, 3, double, aligned_highp> aligned_highp_dmat4x3;
803
805 typedef mat<4, 3, double, aligned_mediump> aligned_mediump_dmat4x3;
806
808 typedef mat<4, 3, double, aligned_lowp> aligned_lowp_dmat4x3;
809
811 typedef mat<4, 3, float, packed_highp> packed_highp_mat4x3;
812
814 typedef mat<4, 3, float, packed_mediump> packed_mediump_mat4x3;
815
817 typedef mat<4, 3, float, packed_lowp> packed_lowp_mat4x3;
818
820 typedef mat<4, 3, double, packed_highp> packed_highp_dmat4x3;
821
823 typedef mat<4, 3, double, packed_mediump> packed_mediump_dmat4x3;
824
826 typedef mat<4, 3, double, packed_lowp> packed_lowp_dmat4x3;
827
828 // -- *mat4x4 --
829
831 typedef mat<4, 4, float, aligned_highp> aligned_highp_mat4x4;
832
834 typedef mat<4, 4, float, aligned_mediump> aligned_mediump_mat4x4;
835
837 typedef mat<4, 4, float, aligned_lowp> aligned_lowp_mat4x4;
838
840 typedef mat<4, 4, double, aligned_highp> aligned_highp_dmat4x4;
841
843 typedef mat<4, 4, double, aligned_mediump> aligned_mediump_dmat4x4;
844
846 typedef mat<4, 4, double, aligned_lowp> aligned_lowp_dmat4x4;
847
849 typedef mat<4, 4, float, packed_highp> packed_highp_mat4x4;
850
852 typedef mat<4, 4, float, packed_mediump> packed_mediump_mat4x4;
853
855 typedef mat<4, 4, float, packed_lowp> packed_lowp_mat4x4;
856
858 typedef mat<4, 4, double, packed_highp> packed_highp_dmat4x4;
859
861 typedef mat<4, 4, double, packed_mediump> packed_mediump_dmat4x4;
862
864 typedef mat<4, 4, double, packed_lowp> packed_lowp_dmat4x4;
865
866 // -- default --
867
868 #if(defined(GLM_PRECISION_LOWP_FLOAT))
869 typedef aligned_lowp_vec1 aligned_vec1;
870 typedef aligned_lowp_vec2 aligned_vec2;
871 typedef aligned_lowp_vec3 aligned_vec3;
872 typedef aligned_lowp_vec4 aligned_vec4;
873 typedef packed_lowp_vec1 packed_vec1;
874 typedef packed_lowp_vec2 packed_vec2;
875 typedef packed_lowp_vec3 packed_vec3;
876 typedef packed_lowp_vec4 packed_vec4;
877
878 typedef aligned_lowp_mat2 aligned_mat2;
879 typedef aligned_lowp_mat3 aligned_mat3;
880 typedef aligned_lowp_mat4 aligned_mat4;
881 typedef packed_lowp_mat2 packed_mat2;
882 typedef packed_lowp_mat3 packed_mat3;
883 typedef packed_lowp_mat4 packed_mat4;
884
885 typedef aligned_lowp_mat2x2 aligned_mat2x2;
886 typedef aligned_lowp_mat2x3 aligned_mat2x3;
887 typedef aligned_lowp_mat2x4 aligned_mat2x4;
888 typedef aligned_lowp_mat3x2 aligned_mat3x2;
889 typedef aligned_lowp_mat3x3 aligned_mat3x3;
890 typedef aligned_lowp_mat3x4 aligned_mat3x4;
891 typedef aligned_lowp_mat4x2 aligned_mat4x2;
892 typedef aligned_lowp_mat4x3 aligned_mat4x3;
893 typedef aligned_lowp_mat4x4 aligned_mat4x4;
894 typedef packed_lowp_mat2x2 packed_mat2x2;
895 typedef packed_lowp_mat2x3 packed_mat2x3;
896 typedef packed_lowp_mat2x4 packed_mat2x4;
897 typedef packed_lowp_mat3x2 packed_mat3x2;
898 typedef packed_lowp_mat3x3 packed_mat3x3;
899 typedef packed_lowp_mat3x4 packed_mat3x4;
900 typedef packed_lowp_mat4x2 packed_mat4x2;
901 typedef packed_lowp_mat4x3 packed_mat4x3;
902 typedef packed_lowp_mat4x4 packed_mat4x4;
903 #elif(defined(GLM_PRECISION_MEDIUMP_FLOAT))
904 typedef aligned_mediump_vec1 aligned_vec1;
905 typedef aligned_mediump_vec2 aligned_vec2;
906 typedef aligned_mediump_vec3 aligned_vec3;
907 typedef aligned_mediump_vec4 aligned_vec4;
908 typedef packed_mediump_vec1 packed_vec1;
909 typedef packed_mediump_vec2 packed_vec2;
910 typedef packed_mediump_vec3 packed_vec3;
911 typedef packed_mediump_vec4 packed_vec4;
912
913 typedef aligned_mediump_mat2 aligned_mat2;
914 typedef aligned_mediump_mat3 aligned_mat3;
915 typedef aligned_mediump_mat4 aligned_mat4;
916 typedef packed_mediump_mat2 packed_mat2;
917 typedef packed_mediump_mat3 packed_mat3;
918 typedef packed_mediump_mat4 packed_mat4;
919
920 typedef aligned_mediump_mat2x2 aligned_mat2x2;
921 typedef aligned_mediump_mat2x3 aligned_mat2x3;
922 typedef aligned_mediump_mat2x4 aligned_mat2x4;
923 typedef aligned_mediump_mat3x2 aligned_mat3x2;
924 typedef aligned_mediump_mat3x3 aligned_mat3x3;
925 typedef aligned_mediump_mat3x4 aligned_mat3x4;
926 typedef aligned_mediump_mat4x2 aligned_mat4x2;
927 typedef aligned_mediump_mat4x3 aligned_mat4x3;
928 typedef aligned_mediump_mat4x4 aligned_mat4x4;
929 typedef packed_mediump_mat2x2 packed_mat2x2;
930 typedef packed_mediump_mat2x3 packed_mat2x3;
931 typedef packed_mediump_mat2x4 packed_mat2x4;
932 typedef packed_mediump_mat3x2 packed_mat3x2;
933 typedef packed_mediump_mat3x3 packed_mat3x3;
934 typedef packed_mediump_mat3x4 packed_mat3x4;
935 typedef packed_mediump_mat4x2 packed_mat4x2;
936 typedef packed_mediump_mat4x3 packed_mat4x3;
937 typedef packed_mediump_mat4x4 packed_mat4x4;
938 #else //defined(GLM_PRECISION_HIGHP_FLOAT)
939 typedef aligned_highp_vec1 aligned_vec1;
941
943 typedef aligned_highp_vec2 aligned_vec2;
944
946 typedef aligned_highp_vec3 aligned_vec3;
947
949 typedef aligned_highp_vec4 aligned_vec4;
950
952 typedef packed_highp_vec1 packed_vec1;
953
955 typedef packed_highp_vec2 packed_vec2;
956
958 typedef packed_highp_vec3 packed_vec3;
959
961 typedef packed_highp_vec4 packed_vec4;
962
964 typedef aligned_highp_mat2 aligned_mat2;
965
967 typedef aligned_highp_mat3 aligned_mat3;
968
970 typedef aligned_highp_mat4 aligned_mat4;
971
973 typedef packed_highp_mat2 packed_mat2;
974
976 typedef packed_highp_mat3 packed_mat3;
977
979 typedef packed_highp_mat4 packed_mat4;
980
982 typedef aligned_highp_mat2x2 aligned_mat2x2;
983
985 typedef aligned_highp_mat2x3 aligned_mat2x3;
986
988 typedef aligned_highp_mat2x4 aligned_mat2x4;
989
991 typedef aligned_highp_mat3x2 aligned_mat3x2;
992
994 typedef aligned_highp_mat3x3 aligned_mat3x3;
995
997 typedef aligned_highp_mat3x4 aligned_mat3x4;
998
1000 typedef aligned_highp_mat4x2 aligned_mat4x2;
1001
1003 typedef aligned_highp_mat4x3 aligned_mat4x3;
1004
1006 typedef aligned_highp_mat4x4 aligned_mat4x4;
1007
1009 typedef packed_highp_mat2x2 packed_mat2x2;
1010
1012 typedef packed_highp_mat2x3 packed_mat2x3;
1013
1015 typedef packed_highp_mat2x4 packed_mat2x4;
1016
1018 typedef packed_highp_mat3x2 packed_mat3x2;
1019
1021 typedef packed_highp_mat3x3 packed_mat3x3;
1022
1024 typedef packed_highp_mat3x4 packed_mat3x4;
1025
1027 typedef packed_highp_mat4x2 packed_mat4x2;
1028
1030 typedef packed_highp_mat4x3 packed_mat4x3;
1031
1033 typedef packed_highp_mat4x4 packed_mat4x4;
1034 #endif//GLM_PRECISION
1035
1036 #if(defined(GLM_PRECISION_LOWP_DOUBLE))
1037 typedef aligned_lowp_dvec1 aligned_dvec1;
1038 typedef aligned_lowp_dvec2 aligned_dvec2;
1039 typedef aligned_lowp_dvec3 aligned_dvec3;
1040 typedef aligned_lowp_dvec4 aligned_dvec4;
1041 typedef packed_lowp_dvec1 packed_dvec1;
1042 typedef packed_lowp_dvec2 packed_dvec2;
1043 typedef packed_lowp_dvec3 packed_dvec3;
1044 typedef packed_lowp_dvec4 packed_dvec4;
1045
1046 typedef aligned_lowp_dmat2 aligned_dmat2;
1047 typedef aligned_lowp_dmat3 aligned_dmat3;
1048 typedef aligned_lowp_dmat4 aligned_dmat4;
1049 typedef packed_lowp_dmat2 packed_dmat2;
1050 typedef packed_lowp_dmat3 packed_dmat3;
1051 typedef packed_lowp_dmat4 packed_dmat4;
1052
1053 typedef aligned_lowp_dmat2x2 aligned_dmat2x2;
1054 typedef aligned_lowp_dmat2x3 aligned_dmat2x3;
1055 typedef aligned_lowp_dmat2x4 aligned_dmat2x4;
1056 typedef aligned_lowp_dmat3x2 aligned_dmat3x2;
1057 typedef aligned_lowp_dmat3x3 aligned_dmat3x3;
1058 typedef aligned_lowp_dmat3x4 aligned_dmat3x4;
1059 typedef aligned_lowp_dmat4x2 aligned_dmat4x2;
1060 typedef aligned_lowp_dmat4x3 aligned_dmat4x3;
1061 typedef aligned_lowp_dmat4x4 aligned_dmat4x4;
1062 typedef packed_lowp_dmat2x2 packed_dmat2x2;
1063 typedef packed_lowp_dmat2x3 packed_dmat2x3;
1064 typedef packed_lowp_dmat2x4 packed_dmat2x4;
1065 typedef packed_lowp_dmat3x2 packed_dmat3x2;
1066 typedef packed_lowp_dmat3x3 packed_dmat3x3;
1067 typedef packed_lowp_dmat3x4 packed_dmat3x4;
1068 typedef packed_lowp_dmat4x2 packed_dmat4x2;
1069 typedef packed_lowp_dmat4x3 packed_dmat4x3;
1070 typedef packed_lowp_dmat4x4 packed_dmat4x4;
1071 #elif(defined(GLM_PRECISION_MEDIUMP_DOUBLE))
1072 typedef aligned_mediump_dvec1 aligned_dvec1;
1073 typedef aligned_mediump_dvec2 aligned_dvec2;
1074 typedef aligned_mediump_dvec3 aligned_dvec3;
1075 typedef aligned_mediump_dvec4 aligned_dvec4;
1076 typedef packed_mediump_dvec1 packed_dvec1;
1077 typedef packed_mediump_dvec2 packed_dvec2;
1078 typedef packed_mediump_dvec3 packed_dvec3;
1079 typedef packed_mediump_dvec4 packed_dvec4;
1080
1081 typedef aligned_mediump_dmat2 aligned_dmat2;
1082 typedef aligned_mediump_dmat3 aligned_dmat3;
1083 typedef aligned_mediump_dmat4 aligned_dmat4;
1084 typedef packed_mediump_dmat2 packed_dmat2;
1085 typedef packed_mediump_dmat3 packed_dmat3;
1086 typedef packed_mediump_dmat4 packed_dmat4;
1087
1088 typedef aligned_mediump_dmat2x2 aligned_dmat2x2;
1089 typedef aligned_mediump_dmat2x3 aligned_dmat2x3;
1090 typedef aligned_mediump_dmat2x4 aligned_dmat2x4;
1091 typedef aligned_mediump_dmat3x2 aligned_dmat3x2;
1092 typedef aligned_mediump_dmat3x3 aligned_dmat3x3;
1093 typedef aligned_mediump_dmat3x4 aligned_dmat3x4;
1094 typedef aligned_mediump_dmat4x2 aligned_dmat4x2;
1095 typedef aligned_mediump_dmat4x3 aligned_dmat4x3;
1096 typedef aligned_mediump_dmat4x4 aligned_dmat4x4;
1097 typedef packed_mediump_dmat2x2 packed_dmat2x2;
1098 typedef packed_mediump_dmat2x3 packed_dmat2x3;
1099 typedef packed_mediump_dmat2x4 packed_dmat2x4;
1100 typedef packed_mediump_dmat3x2 packed_dmat3x2;
1101 typedef packed_mediump_dmat3x3 packed_dmat3x3;
1102 typedef packed_mediump_dmat3x4 packed_dmat3x4;
1103 typedef packed_mediump_dmat4x2 packed_dmat4x2;
1104 typedef packed_mediump_dmat4x3 packed_dmat4x3;
1105 typedef packed_mediump_dmat4x4 packed_dmat4x4;
1106 #else //defined(GLM_PRECISION_HIGHP_DOUBLE)
1107 typedef aligned_highp_dvec1 aligned_dvec1;
1109
1111 typedef aligned_highp_dvec2 aligned_dvec2;
1112
1114 typedef aligned_highp_dvec3 aligned_dvec3;
1115
1117 typedef aligned_highp_dvec4 aligned_dvec4;
1118
1120 typedef packed_highp_dvec1 packed_dvec1;
1121
1123 typedef packed_highp_dvec2 packed_dvec2;
1124
1126 typedef packed_highp_dvec3 packed_dvec3;
1127
1129 typedef packed_highp_dvec4 packed_dvec4;
1130
1132 typedef aligned_highp_dmat2 aligned_dmat2;
1133
1135 typedef aligned_highp_dmat3 aligned_dmat3;
1136
1138 typedef aligned_highp_dmat4 aligned_dmat4;
1139
1141 typedef packed_highp_dmat2 packed_dmat2;
1142
1144 typedef packed_highp_dmat3 packed_dmat3;
1145
1147 typedef packed_highp_dmat4 packed_dmat4;
1148
1150 typedef aligned_highp_dmat2x2 aligned_dmat2x2;
1151
1153 typedef aligned_highp_dmat2x3 aligned_dmat2x3;
1154
1156 typedef aligned_highp_dmat2x4 aligned_dmat2x4;
1157
1159 typedef aligned_highp_dmat3x2 aligned_dmat3x2;
1160
1162 typedef aligned_highp_dmat3x3 aligned_dmat3x3;
1163
1165 typedef aligned_highp_dmat3x4 aligned_dmat3x4;
1166
1168 typedef aligned_highp_dmat4x2 aligned_dmat4x2;
1169
1171 typedef aligned_highp_dmat4x3 aligned_dmat4x3;
1172
1174 typedef aligned_highp_dmat4x4 aligned_dmat4x4;
1175
1177 typedef packed_highp_dmat2x2 packed_dmat2x2;
1178
1180 typedef packed_highp_dmat2x3 packed_dmat2x3;
1181
1183 typedef packed_highp_dmat2x4 packed_dmat2x4;
1184
1186 typedef packed_highp_dmat3x2 packed_dmat3x2;
1187
1189 typedef packed_highp_dmat3x3 packed_dmat3x3;
1190
1192 typedef packed_highp_dmat3x4 packed_dmat3x4;
1193
1195 typedef packed_highp_dmat4x2 packed_dmat4x2;
1196
1198 typedef packed_highp_dmat4x3 packed_dmat4x3;
1199
1201 typedef packed_highp_dmat4x4 packed_dmat4x4;
1202 #endif//GLM_PRECISION
1203
1204 #if(defined(GLM_PRECISION_LOWP_INT))
1205 typedef aligned_lowp_ivec1 aligned_ivec1;
1206 typedef aligned_lowp_ivec2 aligned_ivec2;
1207 typedef aligned_lowp_ivec3 aligned_ivec3;
1208 typedef aligned_lowp_ivec4 aligned_ivec4;
1209 #elif(defined(GLM_PRECISION_MEDIUMP_INT))
1210 typedef aligned_mediump_ivec1 aligned_ivec1;
1211 typedef aligned_mediump_ivec2 aligned_ivec2;
1212 typedef aligned_mediump_ivec3 aligned_ivec3;
1213 typedef aligned_mediump_ivec4 aligned_ivec4;
1214 #else //defined(GLM_PRECISION_HIGHP_INT)
1215 typedef aligned_highp_ivec1 aligned_ivec1;
1217
1219 typedef aligned_highp_ivec2 aligned_ivec2;
1220
1222 typedef aligned_highp_ivec3 aligned_ivec3;
1223
1225 typedef aligned_highp_ivec4 aligned_ivec4;
1226
1228 typedef packed_highp_ivec1 packed_ivec1;
1229
1231 typedef packed_highp_ivec2 packed_ivec2;
1232
1234 typedef packed_highp_ivec3 packed_ivec3;
1235
1237 typedef packed_highp_ivec4 packed_ivec4;
1238 #endif//GLM_PRECISION
1239
1240 // -- Unsigned integer definition --
1241
1242 #if(defined(GLM_PRECISION_LOWP_UINT))
1243 typedef aligned_lowp_uvec1 aligned_uvec1;
1244 typedef aligned_lowp_uvec2 aligned_uvec2;
1245 typedef aligned_lowp_uvec3 aligned_uvec3;
1246 typedef aligned_lowp_uvec4 aligned_uvec4;
1247 #elif(defined(GLM_PRECISION_MEDIUMP_UINT))
1248 typedef aligned_mediump_uvec1 aligned_uvec1;
1249 typedef aligned_mediump_uvec2 aligned_uvec2;
1250 typedef aligned_mediump_uvec3 aligned_uvec3;
1251 typedef aligned_mediump_uvec4 aligned_uvec4;
1252 #else //defined(GLM_PRECISION_HIGHP_UINT)
1253 typedef aligned_highp_uvec1 aligned_uvec1;
1255
1257 typedef aligned_highp_uvec2 aligned_uvec2;
1258
1260 typedef aligned_highp_uvec3 aligned_uvec3;
1261
1263 typedef aligned_highp_uvec4 aligned_uvec4;
1264
1266 typedef packed_highp_uvec1 packed_uvec1;
1267
1269 typedef packed_highp_uvec2 packed_uvec2;
1270
1272 typedef packed_highp_uvec3 packed_uvec3;
1273
1275 typedef packed_highp_uvec4 packed_uvec4;
1276 #endif//GLM_PRECISION
1277
1278 #if(defined(GLM_PRECISION_LOWP_BOOL))
1279 typedef aligned_lowp_bvec1 aligned_bvec1;
1280 typedef aligned_lowp_bvec2 aligned_bvec2;
1281 typedef aligned_lowp_bvec3 aligned_bvec3;
1282 typedef aligned_lowp_bvec4 aligned_bvec4;
1283 #elif(defined(GLM_PRECISION_MEDIUMP_BOOL))
1284 typedef aligned_mediump_bvec1 aligned_bvec1;
1285 typedef aligned_mediump_bvec2 aligned_bvec2;
1286 typedef aligned_mediump_bvec3 aligned_bvec3;
1287 typedef aligned_mediump_bvec4 aligned_bvec4;
1288 #else //defined(GLM_PRECISION_HIGHP_BOOL)
1289 typedef aligned_highp_bvec1 aligned_bvec1;
1291
1293 typedef aligned_highp_bvec2 aligned_bvec2;
1294
1296 typedef aligned_highp_bvec3 aligned_bvec3;
1297
1299 typedef aligned_highp_bvec4 aligned_bvec4;
1300
1302 typedef packed_highp_bvec1 packed_bvec1;
1303
1305 typedef packed_highp_bvec2 packed_bvec2;
1306
1308 typedef packed_highp_bvec3 packed_bvec3;
1309
1311 typedef packed_highp_bvec4 packed_bvec4;
1312 #endif//GLM_PRECISION
1313
1315 }//namespace glm
glm::packed_uvec3
packed_highp_uvec3 packed_uvec3
3 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1272
glm::packed_mat2x2
packed_highp_mat2x2 packed_mat2x2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1009
glm::aligned_lowp_mat2x4
mat< 2, 4, float, aligned_lowp > aligned_lowp_mat2x4
2 by 4 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:609
glm::aligned_lowp_bvec4
vec< 4, bool, aligned_lowp > aligned_lowp_bvec4
4 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:363
glm::packed_highp_dvec4
vec< 4, double, packed_highp > packed_highp_dvec4
4 components vector tightly packed in memory of double-precision floating-point numbers using high pr...
Definition: gtc/type_aligned.hpp:375
glm::packed_dmat2x3
packed_highp_dmat2x3 packed_dmat2x3
2 by 3 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1180
glm::packed_lowp_bvec3
vec< 3, bool, packed_lowp > packed_lowp_bvec3
3 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:316
glm::packed_mat4
packed_highp_mat4 packed_mat4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:979
glm::aligned_uvec2
aligned_highp_uvec2 aligned_uvec2
2 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1257
glm::aligned_lowp_bvec2
vec< 2, bool, aligned_lowp > aligned_lowp_bvec2
2 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:179
glm::packed_highp_ivec3
vec< 3, int, packed_highp > packed_highp_ivec3
3 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:292
glm::packed_highp_dmat4x2
mat< 4, 2, double, packed_highp > packed_highp_dmat4x2
4 by 2 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:782
glm::packed_dmat2
packed_highp_dmat2 packed_dmat2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1141
glm::packed_highp_dmat3
mat< 3, 3, double, packed_highp > packed_highp_dmat3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:478
glm::aligned_lowp_mat4x3
mat< 4, 3, float, aligned_lowp > aligned_lowp_mat4x3
4 by 3 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:799
glm::packed_highp_dmat2x4
mat< 2, 4, double, packed_highp > packed_highp_dmat2x4
2 by 4 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:630
glm::aligned_mediump_ivec2
vec< 2, int, aligned_mediump > aligned_mediump_ivec2
2 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:158
glm::packed_mediump_mat4x3
mat< 4, 3, float, packed_mediump > packed_mediump_mat4x3
4 by 3 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:814
glm::packed_ivec3
packed_highp_ivec3 packed_ivec3
3 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1234
glm::aligned_highp_dmat3x4
mat< 3, 4, double, aligned_highp > aligned_highp_dmat3x4
3 by 4 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:726
glm::packed_mediump_dmat3x3
mat< 3, 3, double, packed_mediump > packed_mediump_dmat3x3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:709
glm::packed_mat2
packed_highp_mat2 packed_mat2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:973
glm::packed_lowp_dmat3x4
mat< 3, 4, double, packed_lowp > packed_lowp_dmat3x4
3 by 4 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:750
glm::aligned_mediump_vec2
vec< 2, float, aligned_mediump > aligned_mediump_vec2
2 components vector aligned in memory of single-precision floating-point numbers using medium precisi...
Definition: gtc/type_aligned.hpp:140
glm::aligned_lowp_mat4x4
mat< 4, 4, float, aligned_lowp > aligned_lowp_mat4x4
4 by 4 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:837
glm::packed_mat3
packed_highp_mat3 packed_mat3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:976
glm::packed_dmat4
packed_highp_dmat4 packed_dmat4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1147
glm::packed_vec4
packed_highp_vec4 packed_vec4
4 components vector tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:961
glm::aligned_highp_vec4
vec< 4, float, aligned_highp > aligned_highp_vec4
4 components vector aligned in memory of single-precision floating-point numbers using high precision...
Definition: gtc/type_aligned.hpp:321
glm::packed_highp_dmat4x4
mat< 4, 4, double, packed_highp > packed_highp_dmat4x4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:858
glm::aligned_mediump_dvec1
vec< 1, double, aligned_mediump > aligned_mediump_dvec1
1 component vector aligned in memory of double-precision floating-point numbers using medium precisio...
Definition: gtc/type_aligned.hpp:57
glm::aligned_highp_dmat3x3
mat< 3, 3, double, aligned_highp > aligned_highp_dmat3x3
3 by 3 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:688
glm::packed_dvec3
packed_highp_dvec3 packed_dvec3
3 components vector tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1126
glm::packed_mediump_dvec1
vec< 1, double, packed_mediump > packed_mediump_dvec1
1 component vector tightly packed in memory of double-precision floating-point numbers using medium p...
Definition: gtc/type_aligned.hpp:102
glm::packed_uvec1
packed_highp_uvec1 packed_uvec1
1 component vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1266
glm::packed_lowp_mat3x4
mat< 3, 4, float, packed_lowp > packed_lowp_mat3x4
3 by 4 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:741
glm::aligned_lowp_uvec1
vec< 1, uint, aligned_lowp > aligned_lowp_uvec1
1 component vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:78
glm::packed_lowp_dmat2x4
mat< 2, 4, double, packed_lowp > packed_lowp_dmat2x4
2 by 4 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:636
glm::aligned_ivec3
aligned_highp_ivec3 aligned_ivec3
3 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1222
glm::packed_highp_dmat3x4
mat< 3, 4, double, packed_highp > packed_highp_dmat3x4
3 by 4 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:744
glm::packed_vec2
packed_highp_vec2 packed_vec2
2 components vector tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:955
glm::packed_highp_uvec1
vec< 1, uint, packed_highp > packed_highp_uvec1
1 component vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:117
glm::packed_lowp_mat2x2
mat< 2, 2, float, packed_lowp > packed_lowp_mat2x2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:551
glm::packed_highp_bvec1
vec< 1, bool, packed_highp > packed_highp_bvec1
1 component vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:126
glm::aligned_bvec4
aligned_highp_bvec4 aligned_bvec4
4 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:1299
glm::aligned_vec3
aligned_highp_vec3 aligned_vec3
3 components vector aligned in memory of single-precision floating-point numbers. ...
Definition: gtc/type_aligned.hpp:946
glm::packed_lowp_dmat3x3
mat< 3, 3, double, packed_lowp > packed_lowp_dmat3x3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:712
glm::aligned_uvec3
aligned_highp_uvec3 aligned_uvec3
3 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1260
glm::aligned_mediump_dmat4x2
mat< 4, 2, double, aligned_mediump > aligned_mediump_dmat4x2
4 by 2 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:767
glm::aligned_highp_mat3
mat< 3, 3, float, aligned_highp > aligned_highp_mat3
3 by 3 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:451
glm::packed_mediump_uvec2
vec< 2, uint, packed_mediump > packed_mediump_uvec2
2 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:212
glm::aligned_highp_vec3
vec< 3, float, aligned_highp > aligned_highp_vec3
3 components vector aligned in memory of single-precision floating-point numbers using high precision...
Definition: gtc/type_aligned.hpp:229
glm::aligned_mat4x3
aligned_highp_mat4x3 aligned_mat4x3
4 by 3 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1003
glm::aligned_lowp_ivec4
vec< 4, int, aligned_lowp > aligned_lowp_ivec4
4 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:345
glm::aligned_highp_mat2
mat< 2, 2, float, aligned_highp > aligned_highp_mat2
2 by 2 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:413
glm::packed_vec1
packed_highp_vec1 packed_vec1
1 component vector tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:952
glm::aligned_lowp_ivec2
vec< 2, int, aligned_lowp > aligned_lowp_ivec2
2 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:161
glm::packed_lowp_dmat4x2
mat< 4, 2, double, packed_lowp > packed_lowp_dmat4x2
4 by 2 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:788
glm::aligned_dvec3
aligned_highp_dvec3 aligned_dvec3
3 components vector aligned in memory of double-precision floating-point numbers. ...
Definition: gtc/type_aligned.hpp:1114
glm::packed_lowp_vec1
vec< 1, float, packed_lowp > packed_lowp_vec1
1 component vector tightly packed in memory of single-precision floating-point numbers using low prec...
Definition: gtc/type_aligned.hpp:96
glm::packed_mediump_bvec3
vec< 3, bool, packed_mediump > packed_mediump_bvec3
3 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:313
glm::aligned_dvec1
aligned_highp_dvec1 aligned_dvec1
1 component vector aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1108
glm::packed_uvec4
packed_highp_uvec4 packed_uvec4
4 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1275
glm::packed_dmat3
packed_highp_dmat3 packed_dmat3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1144
glm::aligned_highp_vec2
vec< 2, float, aligned_highp > aligned_highp_vec2
2 components vector aligned in memory of single-precision floating-point numbers using high precision...
Definition: gtc/type_aligned.hpp:137
glm::aligned_highp_dmat2x2
mat< 2, 2, double, aligned_highp > aligned_highp_dmat2x2
2 by 2 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:536
glm::aligned_lowp_uvec3
vec< 3, uint, aligned_lowp > aligned_lowp_uvec3
3 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:262
glm::aligned_lowp_dvec1
vec< 1, double, aligned_lowp > aligned_lowp_dvec1
1 component vector aligned in memory of double-precision floating-point numbers using low precision a...
Definition: gtc/type_aligned.hpp:60
glm::aligned_mediump_vec1
vec< 1, float, aligned_mediump > aligned_mediump_vec1
1 component vector aligned in memory of single-precision floating-point numbers using medium precisio...
Definition: gtc/type_aligned.hpp:48
glm::packed_lowp_dmat4x3
mat< 4, 3, double, packed_lowp > packed_lowp_dmat4x3
4 by 3 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:826
glm::aligned_lowp_dmat3x4
mat< 3, 4, double, aligned_lowp > aligned_lowp_dmat3x4
3 by 4 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:732
glm::packed_highp_mat4x2
mat< 4, 2, float, packed_highp > packed_highp_mat4x2
4 by 2 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:773
glm::aligned_mediump_mat3x2
mat< 3, 2, float, aligned_mediump > aligned_mediump_mat3x2
3 by 2 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:644
glm::aligned_mediump_mat4x3
mat< 4, 3, float, aligned_mediump > aligned_mediump_mat4x3
4 by 3 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:796
glm::aligned_lowp_dvec3
vec< 3, double, aligned_lowp > aligned_lowp_dvec3
3 components vector aligned in memory of double-precision floating-point numbers using low precision ...
Definition: gtc/type_aligned.hpp:244
glm::packed_mediump_mat2
mat< 2, 2, float, packed_mediump > packed_mediump_mat2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:434
glm::packed_mat3x3
packed_highp_mat3x3 packed_mat3x3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1021
glm::packed_highp_dvec1
vec< 1, double, packed_highp > packed_highp_dvec1
1 component vector tightly packed in memory of double-precision floating-point numbers using high pre...
Definition: gtc/type_aligned.hpp:99
glm::aligned_lowp_dmat3x2
mat< 3, 2, double, aligned_lowp > aligned_lowp_dmat3x2
3 by 2 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:656
glm::packed_mediump_mat3
mat< 3, 3, float, packed_mediump > packed_mediump_mat3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:472
glm::aligned_lowp_mat2
mat< 2, 2, float, aligned_lowp > aligned_lowp_mat2
2 by 2 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:419
glm::packed_dmat4x4
packed_highp_dmat4x4 packed_dmat4x4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1201
glm::aligned_lowp_dmat2x3
mat< 2, 3, double, aligned_lowp > aligned_lowp_dmat2x3
2 by 3 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:580
glm::packed_lowp_mat4
mat< 4, 4, float, packed_lowp > packed_lowp_mat4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:513
glm::packed_highp_vec1
vec< 1, float, packed_highp > packed_highp_vec1
1 component vector tightly packed in memory of single-precision floating-point numbers using high pre...
Definition: gtc/type_aligned.hpp:90
glm::aligned_mediump_mat2x3
mat< 2, 3, float, aligned_mediump > aligned_mediump_mat2x3
2 by 3 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:568
glm::packed_highp_mat2x2
mat< 2, 2, float, packed_highp > packed_highp_mat2x2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:545
glm::aligned_mediump_bvec2
vec< 2, bool, aligned_mediump > aligned_mediump_bvec2
2 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:176
glm::packed_lowp_dmat2
mat< 2, 2, double, packed_lowp > packed_lowp_dmat2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:446
glm::aligned_mediump_dmat2
mat< 2, 2, double, aligned_mediump > aligned_mediump_dmat2
2 by 2 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:425
glm::packed_mediump_vec4
vec< 4, float, packed_mediump > packed_mediump_vec4
4 components vector tightly packed in memory of single-precision floating-point numbers using medium ...
Definition: gtc/type_aligned.hpp:369
glm::aligned_dmat4x2
aligned_highp_dmat4x2 aligned_dmat4x2
4 by 2 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1168
glm::packed_lowp_dmat4x4
mat< 4, 4, double, packed_lowp > packed_lowp_dmat4x4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:864
glm::packed_highp_dmat2x2
mat< 2, 2, double, packed_highp > packed_highp_dmat2x2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:554
glm::packed_lowp_mat3x3
mat< 3, 3, float, packed_lowp > packed_lowp_mat3x3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:703
glm::packed_highp_mat4x3
mat< 4, 3, float, packed_highp > packed_highp_mat4x3
4 by 3 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:811
glm::aligned_mediump_mat3
mat< 3, 3, float, aligned_mediump > aligned_mediump_mat3
3 by 3 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:454
glm::aligned_highp_dmat4x3
mat< 4, 3, double, aligned_highp > aligned_highp_dmat4x3
4 by 3 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:802
glm::aligned_lowp_bvec1
vec< 1, bool, aligned_lowp > aligned_lowp_bvec1
1 component vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:87
glm::aligned_mat2
aligned_highp_mat2 aligned_mat2
2 by 2 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:964
glm::aligned_mediump_dmat4x4
mat< 4, 4, double, aligned_mediump > aligned_mediump_dmat4x4
4 by 4 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:843
glm::aligned_mediump_ivec3
vec< 3, int, aligned_mediump > aligned_mediump_ivec3
3 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:250
glm::aligned_bvec3
aligned_highp_bvec3 aligned_bvec3
3 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:1296
glm::packed_uvec2
packed_highp_uvec2 packed_uvec2
2 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1269
glm::aligned_lowp_dvec4
vec< 4, double, aligned_lowp > aligned_lowp_dvec4
4 components vector aligned in memory of double-precision floating-point numbers using low precision ...
Definition: gtc/type_aligned.hpp:336
glm::aligned_lowp_dmat3
mat< 3, 3, double, aligned_lowp > aligned_lowp_dmat3
3 by 3 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:466
glm::packed_mediump_mat4x4
mat< 4, 4, float, packed_mediump > packed_mediump_mat4x4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:852
glm::aligned_highp_uvec4
vec< 4, uint, aligned_highp > aligned_highp_uvec4
4 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:348
glm::packed_highp_dmat4x3
mat< 4, 3, double, packed_highp > packed_highp_dmat4x3
4 by 3 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:820
glm::packed_lowp_mat4x3
mat< 4, 3, float, packed_lowp > packed_lowp_mat4x3
4 by 3 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:817
glm::aligned_lowp_vec2
vec< 2, float, aligned_lowp > aligned_lowp_vec2
2 components vector aligned in memory of single-precision floating-point numbers using low precision ...
Definition: gtc/type_aligned.hpp:143
glm::packed_lowp_ivec1
vec< 1, int, packed_lowp > packed_lowp_ivec1
1 component vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:114
glm::aligned_lowp_bvec3
vec< 3, bool, aligned_lowp > aligned_lowp_bvec3
3 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:271
glm::aligned_mediump_dmat4
mat< 4, 4, double, aligned_mediump > aligned_mediump_dmat4
4 by 4 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:501
glm::packed_mediump_mat2x4
mat< 2, 4, float, packed_mediump > packed_mediump_mat2x4
2 by 4 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:624
glm::packed_highp_dmat4
mat< 4, 4, double, packed_highp > packed_highp_dmat4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:516
glm::aligned_mediump_mat4x2
mat< 4, 2, float, aligned_mediump > aligned_mediump_mat4x2
4 by 2 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:758
glm::packed_mediump_mat3x4
mat< 3, 4, float, packed_mediump > packed_mediump_mat3x4
3 by 4 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:738
glm::packed_highp_uvec3
vec< 3, uint, packed_highp > packed_highp_uvec3
3 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:301
glm::aligned_dmat2x2
aligned_highp_dmat2x2 aligned_dmat2x2
2 by 2 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1150
glm::packed_mediump_dmat2
mat< 2, 2, double, packed_mediump > packed_mediump_dmat2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:443
glm::packed_highp_mat3x4
mat< 3, 4, float, packed_highp > packed_highp_mat3x4
3 by 4 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:735
glm::packed_mat3x4
packed_highp_mat3x4 packed_mat3x4
3 by 4 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1024
glm::packed_mediump_dmat2x4
mat< 2, 4, double, packed_mediump > packed_mediump_dmat2x4
2 by 4 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:633
glm::packed_mediump_uvec1
vec< 1, uint, packed_mediump > packed_mediump_uvec1
1 component vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:120
glm::aligned_lowp_dmat4
mat< 4, 4, double, aligned_lowp > aligned_lowp_dmat4
4 by 4 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:504
glm::packed_mat4x3
packed_highp_mat4x3 packed_mat4x3
4 by 3 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1030
glm::packed_lowp_ivec4
vec< 4, int, packed_lowp > packed_lowp_ivec4
4 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:390
glm::packed_mediump_ivec4
vec< 4, int, packed_mediump > packed_mediump_ivec4
4 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:387
glm::aligned_mediump_dvec2
vec< 2, double, aligned_mediump > aligned_mediump_dvec2
2 components vector aligned in memory of double-precision floating-point numbers using medium precisi...
Definition: gtc/type_aligned.hpp:149
glm::packed_ivec2
packed_highp_ivec2 packed_ivec2
2 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1231
glm::aligned_ivec1
aligned_highp_ivec1 aligned_ivec1
1 component vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1216
glm::packed_mediump_ivec3
vec< 3, int, packed_mediump > packed_mediump_ivec3
3 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:295
glm::packed_lowp_uvec3
vec< 3, uint, packed_lowp > packed_lowp_uvec3
3 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:307
glm::packed_dmat4x2
packed_highp_dmat4x2 packed_dmat4x2
4 by 2 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1195
glm::aligned_mediump_bvec4
vec< 4, bool, aligned_mediump > aligned_mediump_bvec4
4 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:360
glm::aligned_highp_bvec2
vec< 2, bool, aligned_highp > aligned_highp_bvec2
2 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:173
glm::packed_lowp_vec4
vec< 4, float, packed_lowp > packed_lowp_vec4
4 components vector tightly packed in memory of single-precision floating-point numbers using low pre...
Definition: gtc/type_aligned.hpp:372
glm::aligned_highp_dvec4
vec< 4, double, aligned_highp > aligned_highp_dvec4
4 components vector aligned in memory of double-precision floating-point numbers using high precision...
Definition: gtc/type_aligned.hpp:330
glm::packed_highp_dmat2x3
mat< 2, 3, double, packed_highp > packed_highp_dmat2x3
2 by 3 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:592
glm::aligned_mediump_mat2
mat< 2, 2, float, aligned_mediump > aligned_mediump_mat2
2 by 2 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:416
glm::aligned_mediump_dmat2x4
mat< 2, 4, double, aligned_mediump > aligned_mediump_dmat2x4
2 by 4 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:615
glm::packed_lowp_bvec4
vec< 4, bool, packed_lowp > packed_lowp_bvec4
4 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:408
glm::packed_mediump_dvec2
vec< 2, double, packed_mediump > packed_mediump_dvec2
2 components vector tightly packed in memory of double-precision floating-point numbers using medium ...
Definition: gtc/type_aligned.hpp:194
glm::aligned_highp_dvec2
vec< 2, double, aligned_highp > aligned_highp_dvec2
2 components vector aligned in memory of double-precision floating-point numbers using high precision...
Definition: gtc/type_aligned.hpp:146
glm::aligned_lowp_dmat2x4
mat< 2, 4, double, aligned_lowp > aligned_lowp_dmat2x4
2 by 4 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:618
glm::aligned_mat2x3
aligned_highp_mat2x3 aligned_mat2x3
2 by 3 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:985
glm::packed_lowp_mat2
mat< 2, 2, float, packed_lowp > packed_lowp_mat2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:437
glm::aligned_mediump_ivec4
vec< 4, int, aligned_mediump > aligned_mediump_ivec4
4 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:342
glm::packed_lowp_bvec2
vec< 2, bool, packed_lowp > packed_lowp_bvec2
2 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:224
glm::packed_highp_ivec2
vec< 2, int, packed_highp > packed_highp_ivec2
2 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:200
glm::packed_dmat3x4
packed_highp_dmat3x4 packed_dmat3x4
3 by 4 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1192
glm::packed_mediump_dmat3
mat< 3, 3, double, packed_mediump > packed_mediump_dmat3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:481
glm::aligned_lowp_dmat4x3
mat< 4, 3, double, aligned_lowp > aligned_lowp_dmat4x3
4 by 3 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:808
glm::aligned_highp_dmat4x4
mat< 4, 4, double, aligned_highp > aligned_highp_dmat4x4
4 by 4 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:840
glm::packed_mediump_dmat4x2
mat< 4, 2, double, packed_mediump > packed_mediump_dmat4x2
4 by 2 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:785
glm::packed_mat4x4
packed_highp_mat4x4 packed_mat4x4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1033
glm::packed_highp_mat4
mat< 4, 4, float, packed_highp > packed_highp_mat4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:507
glm::aligned_highp_dmat4
mat< 4, 4, double, aligned_highp > aligned_highp_dmat4
4 by 4 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:498
glm::aligned_highp_dmat3x2
mat< 3, 2, double, aligned_highp > aligned_highp_dmat3x2
3 by 2 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:650
glm::packed_lowp_dvec1
vec< 1, double, packed_lowp > packed_lowp_dvec1
1 component vector tightly packed in memory of double-precision floating-point numbers using low prec...
Definition: gtc/type_aligned.hpp:105
glm::aligned_lowp_mat4
mat< 4, 4, float, aligned_lowp > aligned_lowp_mat4
4 by 4 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:495
glm::packed_mediump_uvec3
vec< 3, uint, packed_mediump > packed_mediump_uvec3
3 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:304
glm::aligned_dmat4x3
aligned_highp_dmat4x3 aligned_dmat4x3
4 by 3 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1171
glm::aligned_lowp_dmat4x2
mat< 4, 2, double, aligned_lowp > aligned_lowp_dmat4x2
4 by 2 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:770
glm::packed_mediump_dmat2x3
mat< 2, 3, double, packed_mediump > packed_mediump_dmat2x3
2 by 3 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:595
glm::aligned_highp_dmat4x2
mat< 4, 2, double, aligned_highp > aligned_highp_dmat4x2
4 by 2 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:764
glm::aligned_mat3x4
aligned_highp_mat3x4 aligned_mat3x4
3 by 4 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:997
glm::aligned_lowp_dmat4x4
mat< 4, 4, double, aligned_lowp > aligned_lowp_dmat4x4
4 by 4 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:846
glm::aligned_mediump_mat4x4
mat< 4, 4, float, aligned_mediump > aligned_mediump_mat4x4
4 by 4 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:834
glm::aligned_mat4
aligned_highp_mat4 aligned_mat4
4 by 4 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:970
glm::packed_lowp_dmat2x2
mat< 2, 2, double, packed_lowp > packed_lowp_dmat2x2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:560
glm::packed_mediump_ivec2
vec< 2, int, packed_mediump > packed_mediump_ivec2
2 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:203
glm::packed_dmat3x2
packed_highp_dmat3x2 packed_dmat3x2
3 by 2 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1186
glm::packed_mediump_dmat4
mat< 4, 4, double, packed_mediump > packed_mediump_dmat4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:519
glm::aligned_lowp_vec3
vec< 3, float, aligned_lowp > aligned_lowp_vec3
3 components vector aligned in memory of single-precision floating-point numbers using low precision ...
Definition: gtc/type_aligned.hpp:235
glm::packed_highp_mat2x4
mat< 2, 4, float, packed_highp > packed_highp_mat2x4
2 by 4 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:621
glm::aligned_highp_mat2x3
mat< 2, 3, float, aligned_highp > aligned_highp_mat2x3
2 by 3 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:565
glm::packed_mediump_mat3x3
mat< 3, 3, float, packed_mediump > packed_mediump_mat3x3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:700
glm::packed_highp_vec4
vec< 4, float, packed_highp > packed_highp_vec4
4 components vector tightly packed in memory of single-precision floating-point numbers using high pr...
Definition: gtc/type_aligned.hpp:366
glm::aligned_uvec1
aligned_highp_uvec1 aligned_uvec1
1 component vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1254
glm::aligned_highp_mat4x4
mat< 4, 4, float, aligned_highp > aligned_highp_mat4x4
4 by 4 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:831
glm::packed_mediump_mat4x2
mat< 4, 2, float, packed_mediump > packed_mediump_mat4x2
4 by 2 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:776
glm::aligned_lowp_mat3x2
mat< 3, 2, float, aligned_lowp > aligned_lowp_mat3x2
3 by 2 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:647
glm::packed_lowp_mat3
mat< 3, 3, float, packed_lowp > packed_lowp_mat3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:475
glm::packed_highp_bvec4
vec< 4, bool, packed_highp > packed_highp_bvec4
4 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:402
glm::aligned_vec1
aligned_highp_vec1 aligned_vec1
1 component vector aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:940
glm::packed_vec3
packed_highp_vec3 packed_vec3
3 components vector tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:958
glm::packed_mat2x3
packed_highp_mat2x3 packed_mat2x3
2 by 3 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1012
glm::aligned_mediump_bvec3
vec< 3, bool, aligned_mediump > aligned_mediump_bvec3
3 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:268
glm::aligned_mediump_uvec1
vec< 1, uint, aligned_mediump > aligned_mediump_uvec1
1 component vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:75
glm::aligned_bvec2
aligned_highp_bvec2 aligned_bvec2
2 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:1293
glm::packed_dmat2x2
packed_highp_dmat2x2 packed_dmat2x2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1177
glm::packed_lowp_mat4x2
mat< 4, 2, float, packed_lowp > packed_lowp_mat4x2
4 by 2 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:779
glm::packed_dmat2x4
packed_highp_dmat2x4 packed_dmat2x4
2 by 4 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1183
glm::aligned_highp_uvec3
vec< 3, uint, aligned_highp > aligned_highp_uvec3
3 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:256
glm::packed_mediump_bvec2
vec< 2, bool, packed_mediump > packed_mediump_bvec2
2 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:221
glm::aligned_bvec1
aligned_highp_bvec1 aligned_bvec1
1 component vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:1290
glm::aligned_mat3x2
aligned_highp_mat3x2 aligned_mat3x2
3 by 2 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:991
glm::aligned_lowp_ivec1
vec< 1, int, aligned_lowp > aligned_lowp_ivec1
1 component vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:69
glm::aligned_mediump_dmat3x3
mat< 3, 3, double, aligned_mediump > aligned_mediump_dmat3x3
3 by 3 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:691
glm::packed_lowp_mat3x2
mat< 3, 2, float, packed_lowp > packed_lowp_mat3x2
3 by 2 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:665
glm::packed_highp_mat2x3
mat< 2, 3, float, packed_highp > packed_highp_mat2x3
2 by 3 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:583
glm::packed_lowp_mat4x4
mat< 4, 4, float, packed_lowp > packed_lowp_mat4x4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:855
glm::aligned_uvec4
aligned_highp_uvec4 aligned_uvec4
4 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:1263
glm::packed_bvec2
packed_highp_bvec2 packed_bvec2
2 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:1305
glm::aligned_highp_mat3x3
mat< 3, 3, float, aligned_highp > aligned_highp_mat3x3
3 by 3 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:679
glm::packed_bvec4
packed_highp_bvec4 packed_bvec4
4 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:1311
glm::aligned_ivec4
aligned_highp_ivec4 aligned_ivec4
4 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1225
glm::packed_highp_mat3x3
mat< 3, 3, float, packed_highp > packed_highp_mat3x3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:697
glm::packed_highp_ivec4
vec< 4, int, packed_highp > packed_highp_ivec4
4 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:384
glm::packed_mat3x2
packed_highp_mat3x2 packed_mat3x2
3 by 2 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1018
glm::aligned_highp_uvec2
vec< 2, uint, aligned_highp > aligned_highp_uvec2
2 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:164
glm::aligned_dmat3
aligned_highp_dmat3 aligned_dmat3
3 by 3 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1135
glm::aligned_highp_ivec3
vec< 3, int, aligned_highp > aligned_highp_ivec3
3 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:247
glm::aligned_lowp_dmat2x2
mat< 2, 2, double, aligned_lowp > aligned_lowp_dmat2x2
2 by 2 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:542
glm::aligned_highp_mat3x2
mat< 3, 2, float, aligned_highp > aligned_highp_mat3x2
3 by 2 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:641
glm::aligned_highp_uvec1
vec< 1, uint, aligned_highp > aligned_highp_uvec1
1 component vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:72
glm::aligned_mat2x4
aligned_highp_mat2x4 aligned_mat2x4
2 by 4 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:988
glm::aligned_mediump_mat4
mat< 4, 4, float, aligned_mediump > aligned_mediump_mat4
4 by 4 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:492
glm::packed_dvec1
packed_highp_dvec1 packed_dvec1
1 component vector tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1120
glm::aligned_dmat2x4
aligned_highp_dmat2x4 aligned_dmat2x4
2 by 4 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1156
glm::packed_mediump_dmat2x2
mat< 2, 2, double, packed_mediump > packed_mediump_dmat2x2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:557
glm::packed_lowp_dvec3
vec< 3, double, packed_lowp > packed_lowp_dvec3
3 components vector tightly packed in memory of double-precision floating-point numbers using low pre...
Definition: gtc/type_aligned.hpp:289
glm::aligned_lowp_uvec4
vec< 4, uint, aligned_lowp > aligned_lowp_uvec4
4 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:354
glm::packed_highp_uvec4
vec< 4, uint, packed_highp > packed_highp_uvec4
4 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:393
glm::packed_lowp_mat2x4
mat< 2, 4, float, packed_lowp > packed_lowp_mat2x4
2 by 4 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:627
glm::aligned_vec2
aligned_highp_vec2 aligned_vec2
2 components vector aligned in memory of single-precision floating-point numbers. ...
Definition: gtc/type_aligned.hpp:943
glm::aligned_mat2x2
aligned_highp_mat2x2 aligned_mat2x2
2 by 2 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:982
glm::packed_lowp_dmat3
mat< 3, 3, double, packed_lowp > packed_lowp_dmat3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:484
glm::aligned_dmat3x3
aligned_highp_dmat3x3 aligned_dmat3x3
3 by 3 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1162
glm::packed_highp_dvec2
vec< 2, double, packed_highp > packed_highp_dvec2
2 components vector tightly packed in memory of double-precision floating-point numbers using high pr...
Definition: gtc/type_aligned.hpp:191
glm::aligned_mediump_dmat2x2
mat< 2, 2, double, aligned_mediump > aligned_mediump_dmat2x2
2 by 2 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:539
glm::packed_lowp_uvec1
vec< 1, uint, packed_lowp > packed_lowp_uvec1
1 component vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:123
glm::packed_lowp_uvec2
vec< 2, uint, packed_lowp > packed_lowp_uvec2
2 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:215
glm::packed_dmat4x3
packed_highp_dmat4x3 packed_dmat4x3
4 by 3 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1198
glm::aligned_lowp_dmat3x3
mat< 3, 3, double, aligned_lowp > aligned_lowp_dmat3x3
3 by 3 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:694
glm::packed_highp_mat3
mat< 3, 3, float, packed_highp > packed_highp_mat3
3 by 3 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:469
glm::aligned_dmat2x3
aligned_highp_dmat2x3 aligned_dmat2x3
2 by 3 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1153
glm::aligned_mediump_mat2x2
mat< 2, 2, float, aligned_mediump > aligned_mediump_mat2x2
2 by 2 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:530
glm::aligned_lowp_mat2x2
mat< 2, 2, float, aligned_lowp > aligned_lowp_mat2x2
2 by 2 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:533
glm::packed_mediump_bvec1
vec< 1, bool, packed_mediump > packed_mediump_bvec1
1 component vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:129
glm::packed_lowp_dmat4
mat< 4, 4, double, packed_lowp > packed_lowp_dmat4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:522
glm::packed_ivec1
packed_highp_ivec1 packed_ivec1
1 component vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1228
glm::packed_lowp_bvec1
vec< 1, bool, packed_lowp > packed_lowp_bvec1
1 component vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:132
glm::aligned_dmat3x2
aligned_highp_dmat3x2 aligned_dmat3x2
3 by 2 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1159
glm::packed_highp_dmat3x2
mat< 3, 2, double, packed_highp > packed_highp_dmat3x2
3 by 2 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:668
glm::aligned_ivec2
aligned_highp_ivec2 aligned_ivec2
2 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1219
glm::aligned_dmat4x4
aligned_highp_dmat4x4 aligned_dmat4x4
4 by 4 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1174
glm::packed_highp_dmat3x3
mat< 3, 3, double, packed_highp > packed_highp_dmat3x3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:706
glm::aligned_highp_bvec4
vec< 4, bool, aligned_highp > aligned_highp_bvec4
4 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:357
glm::packed_mediump_bvec4
vec< 4, bool, packed_mediump > packed_mediump_bvec4
4 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:405
glm::packed_highp_mat2
mat< 2, 2, float, packed_highp > packed_highp_mat2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:431
glm::packed_mat2x4
packed_highp_mat2x4 packed_mat2x4
2 by 4 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1015
glm::aligned_lowp_mat4x2
mat< 4, 2, float, aligned_lowp > aligned_lowp_mat4x2
4 by 2 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:761
glm::aligned_mediump_bvec1
vec< 1, bool, aligned_mediump > aligned_mediump_bvec1
1 component vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:84
glm::aligned_highp_dmat2x4
mat< 2, 4, double, aligned_highp > aligned_highp_dmat2x4
2 by 4 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:612
glm::aligned_mediump_mat3x3
mat< 3, 3, float, aligned_mediump > aligned_mediump_mat3x3
3 by 3 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:682
glm::packed_mediump_mat4
mat< 4, 4, float, packed_mediump > packed_mediump_mat4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:510
glm::packed_mediump_vec1
vec< 1, float, packed_mediump > packed_mediump_vec1
1 component vector tightly packed in memory of single-precision floating-point numbers using medium p...
Definition: gtc/type_aligned.hpp:93
glm::aligned_mat4x4
aligned_highp_mat4x4 aligned_mat4x4
4 by 4 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1006
glm::aligned_mat4x2
aligned_highp_mat4x2 aligned_mat4x2
4 by 2 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1000
glm::packed_highp_vec3
vec< 3, float, packed_highp > packed_highp_vec3
3 components vector tightly packed in memory of single-precision floating-point numbers using high pr...
Definition: gtc/type_aligned.hpp:274
glm::aligned_dvec4
aligned_highp_dvec4 aligned_dvec4
4 components vector aligned in memory of double-precision floating-point numbers. ...
Definition: gtc/type_aligned.hpp:1117
glm::aligned_highp_ivec1
vec< 1, int, aligned_highp > aligned_highp_ivec1
1 component vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:63
glm::aligned_lowp_mat3
mat< 3, 3, float, aligned_lowp > aligned_lowp_mat3
3 by 3 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:457
glm::aligned_highp_dmat2
mat< 2, 2, double, aligned_highp > aligned_highp_dmat2
2 by 2 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:422
glm::aligned_dmat3x4
aligned_highp_dmat3x4 aligned_dmat3x4
3 by 4 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1165
glm::packed_bvec3
packed_highp_bvec3 packed_bvec3
3 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:1308
glm::packed_highp_mat4x4
mat< 4, 4, float, packed_highp > packed_highp_mat4x4
4 by 4 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:849
glm::packed_mediump_vec3
vec< 3, float, packed_mediump > packed_mediump_vec3
3 components vector tightly packed in memory of single-precision floating-point numbers using medium ...
Definition: gtc/type_aligned.hpp:277
glm::aligned_lowp_uvec2
vec< 2, uint, aligned_lowp > aligned_lowp_uvec2
2 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:170
glm::aligned_highp_bvec1
vec< 1, bool, aligned_highp > aligned_highp_bvec1
1 component vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:81
glm::packed_highp_bvec2
vec< 2, bool, packed_highp > packed_highp_bvec2
2 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:218
glm::packed_highp_ivec1
vec< 1, int, packed_highp > packed_highp_ivec1
1 component vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:108
glm::aligned_highp_mat2x4
mat< 2, 4, float, aligned_highp > aligned_highp_mat2x4
2 by 4 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:603
glm::packed_lowp_ivec2
vec< 2, int, packed_lowp > packed_lowp_ivec2
2 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:206
glm::packed_highp_dvec3
vec< 3, double, packed_highp > packed_highp_dvec3
3 components vector tightly packed in memory of double-precision floating-point numbers using high pr...
Definition: gtc/type_aligned.hpp:283
glm::aligned_highp_ivec2
vec< 2, int, aligned_highp > aligned_highp_ivec2
2 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:155
glm::aligned_dmat2
aligned_highp_dmat2 aligned_dmat2
2 by 2 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1132
glm::packed_mediump_dmat3x2
mat< 3, 2, double, packed_mediump > packed_mediump_dmat3x2
3 by 2 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:671
glm::aligned_mediump_uvec3
vec< 3, uint, aligned_mediump > aligned_mediump_uvec3
3 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:259
glm::packed_lowp_dvec4
vec< 4, double, packed_lowp > packed_lowp_dvec4
4 components vector tightly packed in memory of double-precision floating-point numbers using low pre...
Definition: gtc/type_aligned.hpp:381
glm::packed_mediump_dvec3
vec< 3, double, packed_mediump > packed_mediump_dvec3
3 components vector tightly packed in memory of double-precision floating-point numbers using medium ...
Definition: gtc/type_aligned.hpp:286
glm::aligned_mediump_dmat2x3
mat< 2, 3, double, aligned_mediump > aligned_mediump_dmat2x3
2 by 3 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:577
glm::aligned_lowp_ivec3
vec< 3, int, aligned_lowp > aligned_lowp_ivec3
3 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:253
glm::aligned_highp_mat2x2
mat< 2, 2, float, aligned_highp > aligned_highp_mat2x2
2 by 2 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:527
glm::aligned_highp_mat4x3
mat< 4, 3, float, aligned_highp > aligned_highp_mat4x3
4 by 3 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:793
glm::aligned_highp_bvec3
vec< 3, bool, aligned_highp > aligned_highp_bvec3
3 components vector aligned in memory of bool values.
Definition: gtc/type_aligned.hpp:265
glm::packed_lowp_vec3
vec< 3, float, packed_lowp > packed_lowp_vec3
3 components vector tightly packed in memory of single-precision floating-point numbers using low pre...
Definition: gtc/type_aligned.hpp:280
glm::aligned_mediump_uvec2
vec< 2, uint, aligned_mediump > aligned_mediump_uvec2
2 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:167
glm::packed_mediump_ivec1
vec< 1, int, packed_mediump > packed_mediump_ivec1
1 component vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:111
glm::aligned_highp_dmat3
mat< 3, 3, double, aligned_highp > aligned_highp_dmat3
3 by 3 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:460
glm::packed_mediump_uvec4
vec< 4, uint, packed_mediump > packed_mediump_uvec4
4 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:396
glm::aligned_mediump_dmat3x2
mat< 3, 2, double, aligned_mediump > aligned_mediump_dmat3x2
3 by 2 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:653
glm::aligned_mediump_dmat3x4
mat< 3, 4, double, aligned_mediump > aligned_mediump_dmat3x4
3 by 4 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:729
glm::packed_mediump_dmat4x3
mat< 4, 3, double, packed_mediump > packed_mediump_dmat4x3
4 by 3 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:823
glm::packed_highp_uvec2
vec< 2, uint, packed_highp > packed_highp_uvec2
2 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:209
glm::aligned_mediump_uvec4
vec< 4, uint, aligned_mediump > aligned_mediump_uvec4
4 components vector aligned in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:351
glm::packed_mediump_dvec4
vec< 4, double, packed_mediump > packed_mediump_dvec4
4 components vector tightly packed in memory of double-precision floating-point numbers using medium ...
Definition: gtc/type_aligned.hpp:378
glm::aligned_vec4
aligned_highp_vec4 aligned_vec4
4 components vector aligned in memory of single-precision floating-point numbers. ...
Definition: gtc/type_aligned.hpp:949
glm::aligned_highp_ivec4
vec< 4, int, aligned_highp > aligned_highp_ivec4
4 components vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:339
glm::aligned_lowp_dvec2
vec< 2, double, aligned_lowp > aligned_lowp_dvec2
2 components vector aligned in memory of double-precision floating-point numbers using low precision ...
Definition: gtc/type_aligned.hpp:152
glm::packed_bvec1
packed_highp_bvec1 packed_bvec1
1 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:1302
glm::packed_lowp_mat2x3
mat< 2, 3, float, packed_lowp > packed_lowp_mat2x3
2 by 3 matrix tightly packed in memory of single-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:589
glm::aligned_lowp_vec1
vec< 1, float, aligned_lowp > aligned_lowp_vec1
1 component vector aligned in memory of single-precision floating-point numbers using low precision a...
Definition: gtc/type_aligned.hpp:51
glm::packed_lowp_vec2
vec< 2, float, packed_lowp > packed_lowp_vec2
2 components vector tightly packed in memory of single-precision floating-point numbers using low pre...
Definition: gtc/type_aligned.hpp:188
glm::aligned_highp_dvec1
vec< 1, double, aligned_highp > aligned_highp_dvec1
1 component vector aligned in memory of double-precision floating-point numbers using high precision ...
Definition: gtc/type_aligned.hpp:54
glm::packed_mediump_mat2x3
mat< 2, 3, float, packed_mediump > packed_mediump_mat2x3
2 by 3 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:586
glm::packed_mediump_mat3x2
mat< 3, 2, float, packed_mediump > packed_mediump_mat3x2
3 by 2 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:662
glm::aligned_mediump_vec4
vec< 4, float, aligned_mediump > aligned_mediump_vec4
4 components vector aligned in memory of single-precision floating-point numbers using medium precisi...
Definition: gtc/type_aligned.hpp:324
glm::packed_dvec4
packed_highp_dvec4 packed_dvec4
4 components vector tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1129
glm::aligned_mediump_dvec4
vec< 4, double, aligned_mediump > aligned_mediump_dvec4
4 components vector aligned in memory of double-precision floating-point numbers using medium precisi...
Definition: gtc/type_aligned.hpp:333
glm::packed_mediump_dmat4x4
mat< 4, 4, double, packed_mediump > packed_mediump_dmat4x4
4 by 4 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:861
glm::packed_mediump_dmat3x4
mat< 3, 4, double, packed_mediump > packed_mediump_dmat3x4
3 by 4 matrix tightly packed in memory of double-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:747
glm::aligned_highp_mat3x4
mat< 3, 4, float, aligned_highp > aligned_highp_mat3x4
3 by 4 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:717
glm::aligned_highp_mat4
mat< 4, 4, float, aligned_highp > aligned_highp_mat4
4 by 4 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:489
glm::packed_lowp_dmat2x3
mat< 2, 3, double, packed_lowp > packed_lowp_dmat2x3
2 by 3 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:598
glm::aligned_mediump_mat3x4
mat< 3, 4, float, aligned_mediump > aligned_mediump_mat3x4
3 by 4 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:720
glm::packed_dmat3x3
packed_highp_dmat3x3 packed_dmat3x3
3 by 3 matrix tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1189
glm::aligned_mat3x3
aligned_highp_mat3x3 aligned_mat3x3
3 by 3 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:994
glm::packed_lowp_ivec3
vec< 3, int, packed_lowp > packed_lowp_ivec3
3 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:298
glm::aligned_dmat4
aligned_highp_dmat4 aligned_dmat4
4 by 4 matrix tightly aligned in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1138
glm::aligned_highp_mat4x2
mat< 4, 2, float, aligned_highp > aligned_highp_mat4x2
4 by 2 matrix aligned in memory of single-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:755
glm::packed_highp_vec2
vec< 2, float, packed_highp > packed_highp_vec2
2 components vector tightly packed in memory of single-precision floating-point numbers using high pr...
Definition: gtc/type_aligned.hpp:182
glm::aligned_lowp_dmat2
mat< 2, 2, double, aligned_lowp > aligned_lowp_dmat2
2 by 2 matrix aligned in memory of double-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:428
glm::packed_lowp_uvec4
vec< 4, uint, packed_lowp > packed_lowp_uvec4
4 components vector tightly packed in memory of unsigned integer numbers.
Definition: gtc/type_aligned.hpp:399
glm::packed_ivec4
packed_highp_ivec4 packed_ivec4
4 components vector tightly packed in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:1237
glm::packed_dvec2
packed_highp_dvec2 packed_dvec2
2 components vector tightly packed in memory of double-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1123
glm::aligned_lowp_mat3x3
mat< 3, 3, float, aligned_lowp > aligned_lowp_mat3x3
3 by 3 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:685
glm::packed_lowp_dmat3x2
mat< 3, 2, double, packed_lowp > packed_lowp_dmat3x2
3 by 2 matrix tightly packed in memory of double-precision floating-point numbers using low precision...
Definition: gtc/type_aligned.hpp:674
glm::packed_highp_mat3x2
mat< 3, 2, float, packed_highp > packed_highp_mat3x2
3 by 2 matrix tightly packed in memory of single-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:659
glm::aligned_mediump_dmat3
mat< 3, 3, double, aligned_mediump > aligned_mediump_dmat3
3 by 3 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:463
glm::aligned_lowp_mat2x3
mat< 2, 3, float, aligned_lowp > aligned_lowp_mat2x3
2 by 3 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:571
glm::aligned_mediump_ivec1
vec< 1, int, aligned_mediump > aligned_mediump_ivec1
1 component vector aligned in memory of signed integer numbers.
Definition: gtc/type_aligned.hpp:66
glm::packed_highp_dmat2
mat< 2, 2, double, packed_highp > packed_highp_dmat2
2 by 2 matrix tightly packed in memory of double-precision floating-point numbers using high precisio...
Definition: gtc/type_aligned.hpp:440
glm::packed_mediump_vec2
vec< 2, float, packed_mediump > packed_mediump_vec2
2 components vector tightly packed in memory of single-precision floating-point numbers using medium ...
Definition: gtc/type_aligned.hpp:185
glm::aligned_mat3
aligned_highp_mat3 aligned_mat3
3 by 3 matrix tightly aligned in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:967
glm::aligned_mediump_dmat4x3
mat< 4, 3, double, aligned_mediump > aligned_mediump_dmat4x3
4 by 3 matrix aligned in memory of double-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:805
glm::packed_mediump_mat2x2
mat< 2, 2, float, packed_mediump > packed_mediump_mat2x2
2 by 2 matrix tightly packed in memory of single-precision floating-point numbers using medium precis...
Definition: gtc/type_aligned.hpp:548
glm::aligned_highp_dmat2x3
mat< 2, 3, double, aligned_highp > aligned_highp_dmat2x3
2 by 3 matrix aligned in memory of double-precision floating-point numbers using high precision arith...
Definition: gtc/type_aligned.hpp:574
glm::aligned_dvec2
aligned_highp_dvec2 aligned_dvec2
2 components vector aligned in memory of double-precision floating-point numbers. ...
Definition: gtc/type_aligned.hpp:1111
glm::aligned_lowp_mat3x4
mat< 3, 4, float, aligned_lowp > aligned_lowp_mat3x4
3 by 4 matrix aligned in memory of single-precision floating-point numbers using low precision arithm...
Definition: gtc/type_aligned.hpp:723
glm::packed_mat4x2
packed_highp_mat4x2 packed_mat4x2
4 by 2 matrix tightly packed in memory of single-precision floating-point numbers.
Definition: gtc/type_aligned.hpp:1027
glm::aligned_lowp_vec4
vec< 4, float, aligned_lowp > aligned_lowp_vec4
4 components vector aligned in memory of single-precision floating-point numbers using low precision ...
Definition: gtc/type_aligned.hpp:327
glm::packed_highp_bvec3
vec< 3, bool, packed_highp > packed_highp_bvec3
3 components vector tightly packed in memory of bool values.
Definition: gtc/type_aligned.hpp:310
glm::packed_lowp_dvec2
vec< 2, double, packed_lowp > packed_lowp_dvec2
2 components vector tightly packed in memory of double-precision floating-point numbers using low pre...
Definition: gtc/type_aligned.hpp:197
glm::aligned_mediump_dvec3
vec< 3, double, aligned_mediump > aligned_mediump_dvec3
3 components vector aligned in memory of double-precision floating-point numbers using medium precisi...
Definition: gtc/type_aligned.hpp:241
glm::aligned_mediump_vec3
vec< 3, float, aligned_mediump > aligned_mediump_vec3
3 components vector aligned in memory of single-precision floating-point numbers using medium precisi...
Definition: gtc/type_aligned.hpp:232
glm::aligned_mediump_mat2x4
mat< 2, 4, float, aligned_mediump > aligned_mediump_mat2x4
2 by 4 matrix aligned in memory of single-precision floating-point numbers using medium precision ari...
Definition: gtc/type_aligned.hpp:606
glm
Definition: common.hpp:20
glm::aligned_highp_dvec3
vec< 3, double, aligned_highp > aligned_highp_dvec3
3 components vector aligned in memory of double-precision floating-point numbers using high precision...
Definition: gtc/type_aligned.hpp:238
glm::aligned_highp_vec1
vec< 1, float, aligned_highp > aligned_highp_vec1
1 component vector aligned in memory of single-precision floating-point numbers using high precision ...
Definition: gtc/type_aligned.hpp:45